@@ -1,6 +1,6 @@
-#' Analysis: Logistic regression
+#' Analysis: Log-logistic
 #'
-#' Logistic models with three (LL.3) or four (LL.4) continuous data parameters. This model was extracted from the drc package.
+#' Logistic models with three (LL.3), four (LL.4) or five (LL.5) continuous data parameters. This model was extracted from the drc package.
 #' @param trat Numeric vector with dependent variable.
 #' @param resp Numeric vector with independent variable.
 #' @param npar Number of model parameters
@@ -10,6 +10,9 @@
 #' @param theme ggplot2 theme (\emph{default} is theme_bw())
 #' @param legend.position legend position (\emph{default} is "top")
 #' @param r2 coefficient of determination of the mean or all values (\emph{default} is all)
+#' @param ic Add interval of confidence
+#' @param fill.ic Color interval of confidence
+#' @param alpha.ic confidence interval transparency level
 #' @param scale Sets x scale (\emph{default} is none, can be "log")
 #' @param point defines whether you want to plot all points ("all") or only the mean ("mean")
 #' @param width.bar	Bar width
@@ -17,17 +20,20 @@
 #' @param pointsize	shape size
 #' @param linesize	line size
 #' @param pointshape format point (default is 21)
+#' @param round round equation
+#' @param xname.formula Name of x in the equation
+#' @param yname.formula Name of y in the equation
 #' @param comment Add text after equation
 #' @return The function returns a list containing the coefficients and their respective values of p; statistical parameters such as AIC, BIC, pseudo-R2, RMSE (root mean square error); largest and smallest estimated value and the graph using ggplot2 with the equation automatically.
 #' @details The three-parameter log-logistic function with lower limit 0 is
-#' \deqn{f(x) = 0 + \frac{d}{1+\exp(b(\log(x)-\log(e)))}}
+#' \deqn{y = 0 + \frac{d}{1+\exp(b(\log(x)-\log(e)))}}
 #' The four-parameter log-logistic function is given by the expression
-#' \deqn{f(x) = c + \frac{d-c}{1+\exp(b(\log(x)-\log(e)))}}
+#' \deqn{y = c + \frac{d-c}{1+\exp(b(\log(x)-\log(e)))}}
 #' The function is symmetric about the inflection point (e).
 #' @author Model imported from the drc package (Ritz et al., 2016)
 #' @author Gabriel Danilo Shimizu
 #' @author Leandro Simoes Azeredo Goncalves
-#' @references Seber, G. A. F. and Wild, C. J (1989) Nonlinear Regression, New York: Wiley \& Sons (p. 330).
+#' @references Seber, G. A. F. and Wild, C. J (1989) Nonlinear Regression, New York: Wiley & Sons (p. 330).
 #' @references Ritz, C.; Strebig, J.C.; Ritz, M.C. Package ‘drc’. Creative Commons: Mountain View, CA, USA, 2016.
 #' @export
 #'
@@ -46,6 +52,9 @@ LL=function(trat,
             legend.position="top",
             error="SE",
             r2="all",
+            ic=FALSE,
+            fill.ic="gray70",
+            alpha.ic=0.5,
             point="all",
             width.bar=NA,
             scale="none",
@@ -53,6 +62,9 @@ LL=function(trat,
             pointsize = 4.5,
             linesize = 0.8,
             pointshape = 21,
+            round=NA,
+            xname.formula="x",
+            yname.formula="y",
             comment=NA){
   requireNamespace("drc")
   requireNamespace("crayon")
@@ -65,40 +77,111 @@ LL=function(trat,
   desvio=ysd
   xmean=tapply(trat,trat,mean)
   if(npar=="LL.3"){mod=drm(resp~trat,fct=LL.3())
+  model=mod
   coef=summary(mod)
+
+  if(is.na(round)==TRUE){
   b=coef$coefficients[,1][1]
   d=coef$coefficients[,1][2]
   e=coef$coefficients[,1][3]
+  e=log(e)}
+
+  if(is.na(round)==FALSE){
+    b=round(coef$coefficients[,1][1],round)
+    d=round(coef$coefficients[,1][2],round)
+    e=round(coef$coefficients[,1][3],round)
+    e=round(log(e),round)}
+
   if(r2=="all"){r2=cor(resp, fitted(mod))^2}
   if(r2=="mean"){r2=cor(ymean, predict(mod,newdata=data.frame(trat=unique(trat))))^2}
   r2=floor(r2*100)/100
-  equation=sprintf("~~~y==frac(%0.3e, 1+e^(%0.3e*(log(x)-log(%0.3e)))) ~~~~~ italic(R^2) == %0.2f",
-                   d,b,e,r2)
+  equation=sprintf("~~~%s==frac(%0.3e, 1+e^{%0.3e*(log(%s) %s %0.3e)}) ~~~~~ italic(R^2) == %0.2f",
+                   yname.formula,
+                   d,
+                   b,
+                   xname.formula,
+                   ifelse(e <= 0, "+", "-"),
+                   abs(e),
+                   r2)
   xp=seq(min(trat),max(trat),length.out = 1000)
   preditos=data.frame(x=xp,
                       y=predict(mod,newdata = data.frame(trat=xp)))
   }
-  if(npar=="LL.4"){mod=drm(resp~trat,fct=LL.4())
+  if(npar=="LL.5"){mod=drm(resp~trat,fct=LL.5())
+  model=mod
   coef=summary(mod)
+
+  if(is.na(round)==TRUE){
   b=coef$coefficients[,1][1]
   c=coef$coefficients[,1][2]
   d=coef$coefficients[,1][3]
   e=coef$coefficients[,1][4]
+  f=coef$coefficients[,1][5]
+  e=log(e)
+  dc=d-c}
+
+  if(is.na(round)==FALSE){
+    b=round(coef$coefficients[,1][1],round)
+    c=round(coef$coefficients[,1][2],round)
+    d=round(coef$coefficients[,1][3],round)
+    e=round(coef$coefficients[,1][4],round)
+    f=round(coef$coefficients[,1][5],round)
+    e=round(log(e),round)
+    dc=d-c}
+
   if(r2=="all"){r2=cor(resp, fitted(mod))^2}
   if(r2=="mean"){r2=cor(ymean, predict(mod,newdata=data.frame(trat=unique(trat))))^2}
   r2=floor(r2*100)/100
-  equation=sprintf("~~~y == %0.3e + frac(%0.3e %s %0.3e, 1+e^(%0.3e*(log(x)-log(%0.3e)))) ~~~~~ italic(R^2) == %0.2f",
+  equation=sprintf("~~~%s == %0.3e + frac(%0.3e, 1+e^(%0.3e*(log(%s) %s %0.3e))^%0.3e) ~~~~~ italic(R^2) == %0.2f",
+                   yname.formula,
                    c,
-                   d,
-                   ifelse(c >= 0, "+", "-"),
-                   abs(c),
+                   dc,
                    b,
-                   e,
+                   xname.formula,
+                   ifelse(e <= 0, "+", "-"),
+                   abs(e),
+                   f,
                    r2)
   xp=seq(min(trat),max(trat),length.out = 1000)
   preditos=data.frame(x=xp,
                       y=predict(mod,newdata = data.frame(trat=xp)))}
   if(is.na(comment)==FALSE){equation=paste(equation,"~\"",comment,"\"")}
+
+  if(npar=="LL.4"){mod=drm(resp~trat,fct=LL.4())
+  model=mod
+  coef=summary(mod)
+
+  if(is.na(round)==TRUE){
+    b=coef$coefficients[,1][1]
+    c=coef$coefficients[,1][2]
+    d=coef$coefficients[,1][3]
+    e=coef$coefficients[,1][4]
+    e=log(e)
+    dc=d-c}
+
+  if(is.na(round)==FALSE){
+    b=round(coef$coefficients[,1][1],round)
+    c=round(coef$coefficients[,1][2],round)
+    d=round(coef$coefficients[,1][3],round)
+    e=round(coef$coefficients[,1][4],round)
+    e=round(log(e),round)
+    dc=d-c}
+
+  if(r2=="all"){r2=cor(resp, fitted(mod))^2}
+  if(r2=="mean"){r2=cor(ymean, predict(mod,newdata=data.frame(trat=unique(trat))))^2}
+  r2=floor(r2*100)/100
+  equation=sprintf("~~~y == %0.3e + frac(%0.3e, 1+e^{%0.3e*(log(x) %s %0.3e)}) ~~~~~ italic(R^2) == %0.2f",
+                   c,
+                   dc,
+                   b,
+                   ifelse(e <= 0, "+", "-"),
+                   abs(e),
+                   r2)
+  xp=seq(min(trat),max(trat),length.out = 1000)
+  preditos=data.frame(x=xp,
+                      y=predict(mod,newdata = data.frame(trat=xp)))}
+  if(is.na(comment)==FALSE){equation=paste(equation,"~\"",comment,"\"")}
+
   predesp=predict(mod)
   predobs=resp
   rmse=sqrt(mean((predesp-predobs)^2))
@@ -110,19 +193,28 @@ LL=function(trat,
   if(point=="mean"){
     graph=ggplot(data,aes(x=xmean,y=ymean))
     if(error!="FALSE"){graph=graph+geom_errorbar(aes(ymin=ymean-ysd,ymax=ymean+ysd),
-                                                 width=width.bar)}
+                                                 width=width.bar,
+                                                 size=linesize)}
     graph=graph+
       geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill="gray")}
   if(point=="all"){
     graph=ggplot(data.frame(trat,resp),aes(x=trat,y=resp))
     graph=graph+
       geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill="gray")}
+  if(ic==TRUE){
+    pred=data.frame(x=xp,
+                    y=predict(mod,interval = "confidence",newdata = data.frame(trat=xp)))
+    preditosic=data.frame(x=c(pred$x,pred$x[length(pred$x):1]),
+                          y=c(pred$y.Lower,pred$y.Upper[length(pred$x):1]))
+    graph=graph+geom_polygon(data=preditosic,aes(x=x,y),fill=fill.ic,alpha=alpha.ic)}
+
   graph=graph+
     theme+
     geom_line(data=preditos,aes(x=x,
                                 y=y,color="black"),size=linesize)+
     scale_color_manual(name="",values=1,label=parse(text = equation))+
     theme(axis.text = element_text(size=textsize,color="black"),
+          axis.title = element_text(size=textsize,color="black"),
           legend.position = legend.position,
           legend.text = element_text(size=textsize),
           legend.direction = "vertical",
@@ -130,7 +222,7 @@ LL=function(trat,
           legend.justification = 0)+
     ylab(ylab)+xlab(xlab)
   if(scale=="log"){graph=graph+scale_x_log10()}
-  temp1=seq(min(trat),max(trat),length.out=10000)
+  temp1=seq(min(trat),max(trat),length.out=5000)
   result=predict(mod,newdata = data.frame(temp=temp1),type="response")
   maximo=temp1[which.max(result)]
   respmax=result[which.max(result)]
