@@ -1,6 +1,6 @@
-#' Analysis: Linear-Plateau Regression
+#' Analysis: Linear-Plateau
 #'
-#' This function performs the quadratic-plateau regression analysis.
+#' This function performs the linear-plateau regression analysis.
 #' @param trat Numeric vector with dependent variable.
 #' @param resp Numeric vector with independent variable.
 #' @param ylab Variable response name (Accepts the \emph{expression}() function)
@@ -16,6 +16,9 @@
 #' @param pointsize	shape size
 #' @param linesize	line size
 #' @param pointshape format point (default is 21)
+#' @param round round equation
+#' @param xname.formula Name of x in the equation
+#' @param yname.formula Name of y in the equation
 #' @param comment Add text after equation
 #' @return The function returns a list containing the coefficients and their respective values of p; statistical parameters such as AIC, BIC, pseudo-R2, RMSE (root mean square error); breakpoint and the graph using ggplot2 with the equation automatically.
 #' @export
@@ -28,10 +31,10 @@
 #' @details
 #' The linear-plateau model is defined by:
 #' First curve:
-#' \deqn{f(x) = \beta_0 + \beta_1 \times x (x < breakpoint)}
+#' \deqn{y = \beta_0 + \beta_1 \times x (x < breakpoint)}
 #'
 #' Second curve:
-#' \deqn{f(x) = \beta_0 + \beta_1 \times breakpoint (x > breakpoint)}
+#' \deqn{y = \beta_0 + \beta_1 \times breakpoint (x > breakpoint)}
 #' @examples
 #' library(AgroReg)
 #' data("granada")
@@ -52,6 +55,9 @@ linear.plateau=function(trat,resp,
                       pointsize = 4.5,
                       linesize = 0.8,
                       pointshape = 21,
+                      round=NA,
+                      xname.formula="x",
+                      yname.formula="y",
                       comment=NA){
   if(is.na(width.bar)==TRUE){width.bar=0.01*mean(trat)}
   lp <- function(x, a, b, c) {
@@ -93,17 +99,32 @@ linear.plateau=function(trat,resp,
   desvio=ysd
   xmean=tapply(trat,trat,mean)
   r2=floor(r2*100)/100
-  s <- sprintf("~~~y == %e %s %e * x ~(x<%e) ~~~~~ italic(R^2) ==  %0.2f",
-               coef(model2)[1],
-               ifelse(coef(model2)[2] >= 0, "+", "-"),
-               abs(coef(model2)[2]),
-               breakpoint,
+
+  if(is.na(round)==TRUE){
+  coef1=coef(model2)[1]
+  coef2=coef(model2)[2]
+  coef3=breakpoint}
+
+  if(is.na(round)==FALSE){
+    coef1=round(coef(model2)[1],round)
+    coef2=round(coef(model2)[2],round)
+    coef3=round(breakpoint,round)}
+
+  s <- sprintf("~~~%s == %e %s %e * %s ~(%s<%e) ~~~~~ italic(R^2) ==  %0.2f",
+               yname.formula,
+               coef1,
+               ifelse(coef2 >= 0, "+", "-"),
+               abs(coef2),
+               xname.formula,
+               xname.formula,
+               coef3,
                r2)
 
   equation=s
   if(is.na(comment)==FALSE){equation=paste(equation,"~\"",comment,"\"")}
   predesp=predict(lp_model)
   predobs=resp
+  model=lp_model
   rmse=sqrt(mean((predesp-predobs)^2))
 
   data=data.frame(xmean,ymean)
@@ -111,7 +132,8 @@ linear.plateau=function(trat,resp,
   if(point=="mean"){
     graph=ggplot(data,aes(x=xmean,y=ymean))
     if(error!="FALSE"){graph=graph+geom_errorbar(aes(ymin=ymean-ysd,ymax=ymean+ysd),
-                                                 width=width.bar)}
+                                                 width=width.bar,
+                                                 size=linesize)}
     graph=graph+
       geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill="gray")}
   if(point=="all"){
@@ -131,6 +153,7 @@ linear.plateau=function(trat,resp,
                                 color="black"),size=linesize)+
     scale_color_manual(name="",values="black",label=parse(text = equation))+
     theme(axis.text = element_text(size=textsize,color="black"),
+          axis.title = element_text(size=textsize,color="black"),
           legend.position = legend.position,
           legend.text = element_text(size=textsize),
           legend.direction = "vertical",
